@@ -8,7 +8,7 @@
 //! extern crate streaming_iterator;
 //!
 //! use postgres::{Connection, TlsMode};
-//! use postgres::types::{Type, ToSql};
+//! use postgres::types::{ToSql, INT4, VARCHAR};
 //! use postgres_binary_copy::BinaryCopyReader;
 //! use streaming_iterator::StreamingIterator;
 //!
@@ -19,7 +19,7 @@
 //!     conn.execute("CREATE TABLE foo (id INT PRIMARY KEY, bar VARCHAR)", &[])
 //!         .unwrap();
 //!
-//!     let types = &[Type::Int4, Type::Varchar];
+//!     let types = &[INT4, VARCHAR];
 //!     let data: Vec<Box<ToSql>> = vec![Box::new(1i32), Box::new("hello"),
 //!                                      Box::new(2i32), Box::new("world")];
 //!     let data = streaming_iterator::convert(data.into_iter()).map_ref(|v| &**v);
@@ -29,7 +29,7 @@
 //!     stmt.copy_in(&[], &mut reader).unwrap();
 //! }
 //! ```
-#![doc(html_root_url="https://docs.rs/postgres-binary-copy/0.4.0")]
+#![doc(html_root_url="https://docs.rs/postgres-binary-copy/0.5.0")]
 #![warn(missing_docs)]
 
 extern crate byteorder;
@@ -65,7 +65,8 @@ pub struct BinaryCopyReader<'a, I> {
 }
 
 impl<'a, I> fmt::Debug for BinaryCopyReader<'a, I>
-    where I: fmt::Debug
+where
+    I: fmt::Debug,
 {
     fn fmt(&self, fmt: &mut fmt::Formatter) -> fmt::Result {
         fmt.debug_struct("BinaryCopyReader")
@@ -77,7 +78,8 @@ impl<'a, I> fmt::Debug for BinaryCopyReader<'a, I>
 }
 
 impl<'a, I> BinaryCopyReader<'a, I>
-    where I: StreamingIterator<Item = ToSql>
+where
+    I: StreamingIterator<Item = ToSql>,
 {
     /// Creates a new `BinaryCopyReader`.
     ///
@@ -130,8 +132,10 @@ impl<'a, I> BinaryCopyReader<'a, I>
                 if idx == 0 {
                     let len = self.types.len();
                     let len = if len > i16::max_value() as usize {
-                        return Err(io::Error::new(io::ErrorKind::InvalidInput,
-                                                  "value too large to transmit"));
+                        return Err(io::Error::new(
+                            io::ErrorKind::InvalidInput,
+                            "value too large to transmit",
+                        ));
                     } else {
                         len as i16
                     };
@@ -145,8 +149,10 @@ impl<'a, I> BinaryCopyReader<'a, I>
                     Ok(IsNull::No) => {
                         let len = self.buf.get_ref().len() as u64 - 4 - len_pos;
                         if len > i32::max_value() as u64 {
-                            return Err(io::Error::new(io::ErrorKind::InvalidInput,
-                                                      "value too large to transmit"));
+                            return Err(io::Error::new(
+                                io::ErrorKind::InvalidInput,
+                                "value too large to transmit",
+                            ));
                         } else {
                             len as i32
                         }
@@ -168,7 +174,8 @@ impl<'a, I> BinaryCopyReader<'a, I>
 }
 
 impl<'a, I> ReadWithInfo for BinaryCopyReader<'a, I>
-    where I: StreamingIterator<Item = ToSql>
+where
+    I: StreamingIterator<Item = ToSql>,
 {
     fn read_with_info(&mut self, buf: &mut [u8], info: &CopyInfo) -> io::Result<usize> {
         if self.buf.position() == self.buf.get_ref().len() as u64 {
@@ -191,7 +198,8 @@ pub trait WriteValue {
 }
 
 impl<F> WriteValue for F
-    where F: FnMut(Option<&[u8]>, &CopyInfo) -> io::Result<()>
+where
+    F: FnMut(Option<&[u8]>, &CopyInfo) -> io::Result<()>,
 {
     fn write_value(&mut self, r: &[u8], info: &CopyInfo) -> io::Result<()> {
         self(Some(r), info)
@@ -221,7 +229,8 @@ pub struct BinaryCopyWriter<W> {
 }
 
 impl<W> fmt::Debug for BinaryCopyWriter<W>
-    where W: fmt::Debug
+where
+    W: fmt::Debug,
 {
     fn fmt(&self, fmt: &mut fmt::Formatter) -> fmt::Result {
         fmt.debug_struct("BinaryCopyWriter")
@@ -234,7 +243,8 @@ impl<W> fmt::Debug for BinaryCopyWriter<W>
 }
 
 impl<W> BinaryCopyWriter<W>
-    where W: WriteValue
+where
+    W: WriteValue,
 {
     /// Creates a new `BinaryCopyWriter`.
     ///
@@ -262,7 +272,10 @@ impl<W> BinaryCopyWriter<W>
         }
 
         if !self.buf.starts_with(HEADER_MAGIC) {
-            return Err(io::Error::new(io::ErrorKind::InvalidInput, "invalid header"));
+            return Err(io::Error::new(
+                io::ErrorKind::InvalidInput,
+                "invalid header",
+            ));
         }
 
         let flags = (&mut &self.buf[HEADER_MAGIC.len()..])
@@ -271,7 +284,10 @@ impl<W> BinaryCopyWriter<W>
         self.has_oids = (flags & 1 << 16) != 0;
 
         if (flags & !0 << 17) != 0 {
-            return Err(io::Error::new(io::ErrorKind::InvalidInput, "critical file format issue"));
+            return Err(io::Error::new(
+                io::ErrorKind::InvalidInput,
+                "critical file format issue",
+            ));
         }
 
         self.buf.clear();
@@ -300,11 +316,12 @@ impl<W> BinaryCopyWriter<W>
         }
     }
 
-    fn read_field_size(&mut self,
-                       buf: &[u8],
-                       info: &CopyInfo,
-                       remaining: usize)
-                       -> io::Result<usize> {
+    fn read_field_size(
+        &mut self,
+        buf: &[u8],
+        info: &CopyInfo,
+        remaining: usize,
+    ) -> io::Result<usize> {
         let (done, nread) = self.read_to(buf, mem::size_of::<i32>())?;
         if !done {
             return Ok(nread);
@@ -333,12 +350,13 @@ impl<W> BinaryCopyWriter<W>
         };
     }
 
-    fn read_field(&mut self,
-                  buf: &[u8],
-                  info: &CopyInfo,
-                  size: usize,
-                  remaining: usize)
-                  -> io::Result<usize> {
+    fn read_field(
+        &mut self,
+        buf: &[u8],
+        info: &CopyInfo,
+        size: usize,
+        remaining: usize,
+    ) -> io::Result<usize> {
         let (done, nread) = self.read_to(buf, size)?;
         if !done {
             return Ok(nread);
@@ -352,7 +370,8 @@ impl<W> BinaryCopyWriter<W>
 }
 
 impl<W> WriteWithInfo for BinaryCopyWriter<W>
-    where W: WriteValue
+where
+    W: WriteValue,
 {
     fn write_with_info(&mut self, buf: &[u8], info: &CopyInfo) -> io::Result<usize> {
         match self.state {
@@ -361,7 +380,10 @@ impl<W> WriteWithInfo for BinaryCopyWriter<W>
             WriteState::AtFieldSize(remaining) => self.read_field_size(buf, info, remaining),
             WriteState::AtField { size, remaining } => self.read_field(buf, info, size, remaining),
             WriteState::Done => {
-                Err(io::Error::new(io::ErrorKind::InvalidInput, "unexpected input after EOF"))
+                Err(io::Error::new(
+                    io::ErrorKind::InvalidInput,
+                    "unexpected input after EOF",
+                ))
             }
         }
     }
@@ -371,51 +393,58 @@ impl<W> WriteWithInfo for BinaryCopyWriter<W>
 mod test {
     use super::*;
     use postgres::{Connection, TlsMode};
-    use postgres::types::{Type, FromSql, ToSql};
+    use postgres::types::{FromSql, ToSql, INT4, VARCHAR, BYTEA, OID};
     use postgres::stmt::CopyInfo;
     use streaming_iterator::{convert, StreamingIterator};
 
     #[test]
     fn write_basic() {
-        let conn = Connection::connect("postgres://postgres@localhost", TlsMode::None).unwrap();
-        conn.execute("CREATE TEMPORARY TABLE foo (id INT PRIMARY KEY, bar VARCHAR)",
-                     &[])
+        let conn = Connection::connect("postgres://postgres:password@localhost", TlsMode::None)
             .unwrap();
+        conn.execute(
+            "CREATE TEMPORARY TABLE foo (id INT PRIMARY KEY, bar VARCHAR)",
+            &[],
+        ).unwrap();
 
         let stmt = conn.prepare("COPY foo (id, bar) FROM STDIN BINARY")
             .unwrap();
 
-        let types = &[Type::Int4, Type::Varchar];
-        let values: Vec<Box<ToSql>> = vec![Box::new(1i32),
-                                           Box::new("foobar"),
-                                           Box::new(2i32),
-                                           Box::new(None::<String>)];
+        let types = &[INT4, VARCHAR];
+        let values: Vec<Box<ToSql>> = vec![
+            Box::new(1i32),
+            Box::new("foobar"),
+            Box::new(2i32),
+            Box::new(None::<String>),
+        ];
         let values = convert(values.into_iter()).map_ref(|v| &**v);
         let mut reader = BinaryCopyReader::new(types, values);
 
         stmt.copy_in(&[], &mut reader).unwrap();
 
-        let stmt = conn.prepare("SELECT id, bar FROM foo ORDER BY id")
-            .unwrap();
-        assert_eq!(vec![(1i32, Some("foobar".to_string())), (2i32, None)],
-                   stmt.query(&[])
-                       .unwrap()
-                       .into_iter()
-                       .map(|r| (r.get(0), r.get(1)))
-                       .collect::<Vec<(i32, Option<String>)>>());
+        let stmt = conn.prepare("SELECT id, bar FROM foo ORDER BY id").unwrap();
+        assert_eq!(
+            vec![(1i32, Some("foobar".to_string())), (2i32, None)],
+            stmt.query(&[])
+                .unwrap()
+                .into_iter()
+                .map(|r| (r.get(0), r.get(1)))
+                .collect::<Vec<(i32, Option<String>)>>()
+        );
     }
 
     #[test]
     fn write_many_rows() {
-        let conn = Connection::connect("postgres://postgres@localhost", TlsMode::None).unwrap();
-        conn.execute("CREATE TEMPORARY TABLE foo (id INT PRIMARY KEY, bar VARCHAR)",
-                     &[])
+        let conn = Connection::connect("postgres://postgres:password@localhost", TlsMode::None)
             .unwrap();
+        conn.execute(
+            "CREATE TEMPORARY TABLE foo (id INT PRIMARY KEY, bar VARCHAR)",
+            &[],
+        ).unwrap();
 
         let stmt = conn.prepare("COPY foo (id, bar) FROM STDIN BINARY")
             .unwrap();
 
-        let types = &[Type::Int4, Type::Varchar];
+        let types = &[INT4, VARCHAR];
         let mut values: Vec<Box<ToSql>> = vec![];
         for i in 0..10_000i32 {
             values.push(Box::new(i));
@@ -427,8 +456,7 @@ mod test {
 
         stmt.copy_in(&[], &mut reader).unwrap();
 
-        let stmt = conn.prepare("SELECT id, bar FROM foo ORDER BY id")
-            .unwrap();
+        let stmt = conn.prepare("SELECT id, bar FROM foo ORDER BY id").unwrap();
         let result = stmt.query(&[]).unwrap();
         assert_eq!(10000, result.len());
         for (i, row) in result.into_iter().enumerate() {
@@ -439,15 +467,17 @@ mod test {
 
     #[test]
     fn write_big_rows() {
-        let conn = Connection::connect("postgres://postgres@localhost", TlsMode::None).unwrap();
-        conn.execute("CREATE TEMPORARY TABLE foo (id INT PRIMARY KEY, bar BYTEA)",
-                     &[])
+        let conn = Connection::connect("postgres://postgres:password@localhost", TlsMode::None)
             .unwrap();
+        conn.execute(
+            "CREATE TEMPORARY TABLE foo (id INT PRIMARY KEY, bar BYTEA)",
+            &[],
+        ).unwrap();
 
         let stmt = conn.prepare("COPY foo (id, bar) FROM STDIN BINARY")
             .unwrap();
 
-        let types = &[Type::Int4, Type::Bytea];
+        let types = &[INT4, BYTEA];
         let mut values: Vec<Box<ToSql>> = vec![];
         for i in 0..2i32 {
             values.push(Box::new(i));
@@ -459,8 +489,7 @@ mod test {
 
         stmt.copy_in(&[], &mut reader).unwrap();
 
-        let stmt = conn.prepare("SELECT id, bar FROM foo ORDER BY id")
-            .unwrap();
+        let stmt = conn.prepare("SELECT id, bar FROM foo ORDER BY id").unwrap();
         let result = stmt.query(&[]).unwrap();
         assert_eq!(2, result.len());
         for (i, row) in result.into_iter().enumerate() {
@@ -471,10 +500,12 @@ mod test {
 
     #[test]
     fn read_basic() {
-        let conn = Connection::connect("postgres://postgres@localhost", TlsMode::None).unwrap();
-        conn.execute("CREATE TEMPORARY TABLE foo (id SERIAL PRIMARY KEY, bar INT)",
-                     &[])
+        let conn = Connection::connect("postgres://postgres:password@localhost", TlsMode::None)
             .unwrap();
+        conn.execute(
+            "CREATE TEMPORARY TABLE foo (id SERIAL PRIMARY KEY, bar INT)",
+            &[],
+        ).unwrap();
         conn.execute("INSERT INTO foo (bar) VALUES (1), (2), (NULL), (4)", &[])
             .unwrap();
 
@@ -483,8 +514,8 @@ mod test {
         {
             let writer = |r: Option<&[u8]>, _: &CopyInfo| {
                 match r {
-                    Some(r) => out.push(Option::<i32>::from_sql(&Type::Int4, r).unwrap()),
-                    None => out.push(Option::<i32>::from_sql_null(&Type::Int4).unwrap()),
+                    Some(r) => out.push(Option::<i32>::from_sql(&INT4, r).unwrap()),
+                    None => out.push(Option::<i32>::from_sql_null(&INT4).unwrap()),
                 }
                 Ok(())
             };
@@ -501,7 +532,8 @@ mod test {
 
     #[test]
     fn read_many_rows() {
-        let conn = Connection::connect("postgres://postgres@localhost", TlsMode::None).unwrap();
+        let conn = Connection::connect("postgres://postgres:password@localhost", TlsMode::None)
+            .unwrap();
         conn.execute("CREATE TEMPORARY TABLE foo (id INT)", &[])
             .unwrap();
 
@@ -516,7 +548,7 @@ mod test {
 
         {
             let writer = |r: Option<&[u8]>, _: &CopyInfo| {
-                out.push(i32::from_sql(&Type::Int4, r.unwrap()).unwrap());
+                out.push(i32::from_sql(&INT4, r.unwrap()).unwrap());
                 Ok(())
             };
 
@@ -532,10 +564,12 @@ mod test {
 
     #[test]
     fn read_big_rows() {
-        let conn = Connection::connect("postgres://postgres@localhost", TlsMode::None).unwrap();
-        conn.execute("CREATE TEMPORARY TABLE foo (id INT PRIMARY KEY, bar BYTEA)",
-                     &[])
+        let conn = Connection::connect("postgres://postgres:password@localhost", TlsMode::None)
             .unwrap();
+        conn.execute(
+            "CREATE TEMPORARY TABLE foo (id INT PRIMARY KEY, bar BYTEA)",
+            &[],
+        ).unwrap();
 
         let mut expected = vec![];
         let stmt = conn.prepare("INSERT INTO foo (id, bar) VALUES ($1, $2)")
@@ -550,15 +584,16 @@ mod test {
 
         {
             let writer = |r: Option<&[u8]>, _: &CopyInfo| {
-                out.push(Vec::<u8>::from_sql(&Type::Bytea, r.unwrap()).unwrap());
+                out.push(Vec::<u8>::from_sql(&BYTEA, r.unwrap()).unwrap());
                 Ok(())
             };
 
             let mut writer = BinaryCopyWriter::new(writer);
 
-            let stmt = conn.prepare("COPY (SELECT bar FROM foo ORDER BY id) TO STDOUT (FORMAT \
-                                     binary)")
-                .unwrap();
+            let stmt = conn.prepare(
+                "COPY (SELECT bar FROM foo ORDER BY id) TO STDOUT (FORMAT \
+                                     binary)",
+            ).unwrap();
             stmt.copy_out(&[], &mut writer).unwrap();
         }
 
@@ -567,7 +602,8 @@ mod test {
 
     #[test]
     fn read_with_oids() {
-        let conn = Connection::connect("postgres://postgres@localhost", TlsMode::None).unwrap();
+        let conn = Connection::connect("postgres://postgres:password@localhost", TlsMode::None)
+            .unwrap();
         conn.execute("CREATE TEMPORARY TABLE foo (id INT) WITH OIDS", &[])
             .unwrap();
         conn.execute("INSERT INTO foo (id) VALUES (1), (2), (3), (4)", &[])
@@ -579,9 +615,9 @@ mod test {
         {
             let writer = |r: Option<&[u8]>, _: &CopyInfo| {
                 if oids.len() > out.len() {
-                    out.push(i32::from_sql(&Type::Bytea, r.unwrap()).unwrap());
+                    out.push(i32::from_sql(&BYTEA, r.unwrap()).unwrap());
                 } else {
-                    oids.push(u32::from_sql(&Type::Oid, r.unwrap()).unwrap());
+                    oids.push(u32::from_sql(&OID, r.unwrap()).unwrap());
                 }
                 Ok(())
             };
